<?php
/**
 * Blackbird MenuManager Module
 *
 * NOTICE OF LICENSE
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@bird.eu so we can send you a copy immediately.
 *
 * @category            Blackbird
 * @package		Blackbird_MenuManager
 * @copyright           Copyright (c) 2016 Blackbird (http://black.bird.eu)
 * @author		Blackbird Team
 */
namespace FiloBlu\ExtBlackbirdMenuManager\Block\Adminhtml\Menu\Edit;

use Magento\Backend\Block\Widget\Form\Generic;
use Blackbird\MenuManager\Controller\Adminhtml\Menu\Edit;

class Main extends \Blackbird\MenuManager\Block\Adminhtml\Menu\Edit\Main
{

    protected function _prepareForm()
    {
        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('menu_');

        $menu = $this->_coreRegistry->registry(Edit::REGISTRY_CODE);
        if ($menu) {
            $form->addField('menu_id', 'hidden', ['name' => 'id']);
        }

        $fieldSet = $form->addFieldset(
            'menu_fieldset',
            ['legend' => __('Menu Data'), 'class' => 'fieldset-wide', 'collapsable' => true]
        );

        $fieldSet->addField(
            'title',
            'text',
            [
                'name'  => 'title',
                'label' => __('Title'),
                'class' => 'required',
                'required' => true,
            ]
        );

        $fieldSet->addField(
            'identifier',
            'text',
            [
                'name'  => 'identifier',
                'label' => __('Identifier'),
                'class' => 'required',
                'required' => true,
            ]
        );

        $fieldSet->addField(
            'menu_status',
            'select',
            [
                'name' => 'menu_status',
                'label' => 'Status',
                'class' => 'required',
                 'required' => true,
                'values' => $this->_enabledisabled->toOptionArray(),
            ]
        );

        $fieldSet->addField(
            'stores',
            'multiselect',
            [
                'name' => 'stores',
                'label' => __('Store View'),
                'title' => __('Store View'),
                'required' => true,
                'values' => $this->_systemStore->getStoreValuesForForm(false, true),
            ]
        );
        
        $objectManager = \Magento\Framework\App\ObjectManager::getInstance();
        $groupOptions = $objectManager->get('\FiloBlu\ExtMagentoWidget\Model\ResourceModel\Group\Collection')->toOptionArray();
        
        $fieldSet->addField(
            'customer_group', 'multiselect', [
            'name' => 'customer_group[]',
            'label' => __('Customer Group'),
            'title' => __('Customer Group'),
            'values' => $groupOptions,
            'disabled' => false
                ]
        );


        $this->setForm($form);
    }
}